@@ -68,7 +68,7 @@ class KeyAlreadyExists(KeyError):
 
 
 dialect_names = '''drizzle firebird mssql mysql oracle postgresql
-                   sqlite sybase sqlalchemy'''.split()
+                   sqlite sybase sqlalchemy django'''.split()
 
 
 def _dump(sql, *multiparams, **params):
@@ -80,28 +80,6 @@ for engine_name in ('postgresql', 'sqlite', 'mysql', 'oracle', 'mssql'):
                                                  strategy='mock',
                                                  executor=_dump)                                                              
 
-
-from sqlalchemy.sql import compiler
-
-from psycopg2.extensions import adapt as sqlescape
-# or use the appropiate escape function from your db driver
-
-def compile_query(query):
-    dialect = query.session.bind.dialect
-    statement = query.statement
-    comp = compiler.SQLCompiler(dialect, statement)
-    comp.compile()
-    enc = dialect.encoding
-    params = {}
-    for k,v in comp.params.iteritems():
-        if isinstance(v, unicode):
-            v = v.encode(enc)
-        params[k] = sqlescape(v)
-    return (comp.string.encode(enc) % params).decode(enc)
-    
-
-
-
 class Table(object):
     """
     >>> data = '''
@@ -133,7 +111,7 @@ class Table(object):
             elif hasattr(data, 'lower'):  # duck-type string test
                 if os.path.isfile(data):
                     (file_path, file_extension) = os.path.splitext(data)
-                    self.table_name = os.path.split(file_path)[1]
+                    self.table_name = os.path.split(file_path)[1].lower()
         self.table_name = self.table_name or \
                           'generated_table%s' % Table.table_index
         self.table_name = reshape.clean_key_name(self.table_name)
@@ -322,9 +300,48 @@ class Table(object):
                 ", ".join(sqla_imports), self.table_name, result)
             result = textwrap.dedent(result)
         return result
+
+    def django_models(self, metadata_source=None):
+        sql = self.sql(dialect='postgresql', inserts=False, creates=True,
+            drops=True, metadata_source=metadata_source)
+        u = sql.split(';\n')
+
+        try:
+            import django
+        except ImportError:
+            print('Cannot find Django on the current path. Is it installed?')
+            django = None
+
+        if django:
+            from django.conf import settings
+            from django.core import management
+            from django import setup
+
+            import sqlite3
+            import os
+
+            db_filename = 'generated_db.db'
+
+            conn = sqlite3.connect(db_filename)
+            c = conn.cursor()
+            for i in u:
+                c.execute(i)
+
+            if not settings.configured:
+                settings.configure(
+                    DEBUG='on',
+                    SECRET_KEY='1234',
+                    ALLOWED_HOSTS='localhost',
+                    DATABASES = {'default' : {'NAME':db_filename,'ENGINE':'django.db.backends.sqlite3'}},
+                    )
+                django.setup()
+            management.call_command('inspectdb', interactive=False)
+            os.remove(db_filename)
         
     _datetime_format = {}  # TODO: test the various RDBMS for power to read the standard
     def _prep_datum(self, datum, dialect, col):
+        if datum is None:
+            return 'NULL'
         pytype = self.columns[col]['pytype']
         if pytype == datetime.datetime:
             datum = dateutil.parser.parse(datum)
@@ -426,6 +443,7 @@ class Table(object):
                                        'is_unique': set([v, ])}
                 else:
                     col = self.columns[k]
+                    old_sample_datum = col.get('sample_datum')
                     col['sample_datum'] = th.best_representative(
                         col['sample_datum'], v)
                     if (v is None):
